==> go.php?file=PhoenixStyle1.54601.zip: PhoenixStyleMod_Firelands/Localization/localization-enEN.lua <==
﻿


function psfirellocalem()

psfirellastmoduleloadtxt	= "Firelands"

psfirelgot			= "Got"
psfirelgotm			= "got"
psfirelwhogot			= "Who got"
psfireltotal			= "total"
psfirelgotinm			= "got in"
psfirelgotinf			= "got in"
psfirediedfrom			= "died from"
psfirehealedhimself		= "healed"
psfireldamagefrom		= "Damage from"
psfiretxtopt512			= "|tip2 How much heal boss received from |sid99332|id"
psfiretxtopt515			= "|tip1 If someone else get damage from |sid100833|id - shows who tank add etc (|cffff0000heroic|r)"
psfiretxtopt516			= "|tip1 If more than 1 raider get damage from |sid100838|id - shows info in chat (|cffff0000heroic|r)"
psfiretxtopt533			= "|tip1 Announce if NOT a player got |sid100359|id"
psfiretxtopt544			= "|tip2 Who interrupted |sid99947|id by damaging add (total)"
psfiretxtopt551			= "|tip1 If a player is killed by crystal with |sid99403|id - show info (who refresh it - |cffff0000heroic|r)"
psfiretxtopt552			= "|tip1 If a player is killed by |sid99353|id with |sid99403|id - show info (who refresh it - |cffff0000heroic|r)"
psfiretxtopt553			= "|tip1 Show who had |sid99516|id if it was failed (|cffff0000heroic|r)"
psfiretxtopt561			= "|tip1 Who did damage with |sid98620|id"
psfiretxtopt562			= "|tip2 Who did damage with |sid98620|id (total)"
psfiretxtopt563			= "|tip1 Who did not take damage from |sid100214|id (exclude people with/after 7 sec of |sid100215|id)"
psfiretxtopt564			= "|tip2 Who did not take damage from |sid100214|id (exclude people with/after 7 sec of |sid100215|id) - total"
psfiretxtopt571			= "|tip1 Who triggered |sid98164|id if someone died from it (|cffff0000range check, not 100% accurately|r)"
psfiretxtopt572			= "|tip1 Total damage to Live Meteors if more then 250k (may be excess damage)"
psfiretxtopt573			= "|tip1 After |sid100259|id shows who made damage and stuns to the add"
psfiretxtopt574			= "|tip2 |sid101233|id - who got damage when it spawned, didn`t run away"


psfiretxtoptt533		= "|s4id100359|id got NOT a player! Buff on"
psfiretxtoptt544		= "|s4id99947|id was interrupted by"
psfiretimes			= "times"
psfirebaleroccrystal		= "Crystal"
psfirenotsure			= "not sure"
psfirewith			= "with"
psfireby			= "by" --от
psfirewhodied			= "who died info"
psfireintershanox		= "Interrupted by"
psfirebabah			= "explode"
psfirebabah2			= "Attacks with |s4id98620,100215,100216,100217|id to players"
psfiremajodamag1		= "Everyone got damage!"
psfiremajodamag2		= "|s4id98474,100212,100213,100214|id no damage on"
psfiremajodamag3		= "no damage on"
psfiremaybeexcessd		= "May be excess damage to"
psfireno			= "NO"
psfirefixate1			= "last one finished %s sec ago on"
psfirediddamageto		= "Did damage to"
psfiredamshared			= "explode shared between"
psfireshanaddopt1		= "AoE from the Spear"
psfireshanaddopt2		= "damage from the Spear"
psfireshanaddopt3		= "excess"


end

==> go.php?file=PhoenixStyle1.54801.zip: PhoenixStyleMod_Firelands/Localization/localization-enEN.lua <==
﻿


function psfirellocalem()

psfirellastmoduleloadtxt	= "Firelands"

psfirelgot			= "Got"
psfirelgotm			= "got"
psfirelwhogot			= "Who got"
psfireltotal			= "total"
psfirelgotinm			= "got in"
psfirelgotinf			= "got in"
psfirediedfrom			= "died from"
psfirehealedhimself		= "healed"
psfireldamagefrom		= "Damage from"
psfiretxtopt512			= "|tip2 How much heal boss received from |sid99332|id"
psfiretxtopt515			= "|tip1 If someone else get damage from |sid100833|id - shows who tank add etc (|cffff0000heroic|r)"
psfiretxtopt516			= "|tip1 If more than 1 raider get damage from |sid100838|id - shows info in chat (|cffff0000heroic|r)"
psfiretxtopt517			= "|tip2 Who used taunts against Cinderweb Spinner (more info in 'in combat info' module)"
psfiretxtopt518			= "|tip2 How much time Cinderweb Drone got |sid100634|id"
psfiretxtopt522			= "|tip2 How much time Liquid Obsidian casts |sid99875|id"
psfiretxtopt533			= "|tip1 Announce if NOT a player got |sid100359|id"
psfiretxtopt544			= "|tip2 Who interrupted |sid99947|id by damaging add (total)"
psfiretxtopt551			= "|tip1 If a player is killed by crystal with |sid99403|id - show info (who refresh it - |cffff0000heroic|r)"
psfiretxtopt552			= "|tip1 If a player is killed by |sid99353|id with |sid99403|id - show info (who refresh it - |cffff0000heroic|r)"
psfiretxtopt553			= "|tip1 Show who had |sid99516|id if it was failed (|cffff0000heroic|r)"
psfiretxtopt561			= "|tip1 Who did damage with |sid98620|id"
psfiretxtopt562			= "|tip2 Who did damage with |sid98620|id (total)"
psfiretxtopt563			= "|tip1 Who did not take damage from |sid100214|id (exclude people with/after 7 sec of |sid100215|id)"
psfiretxtopt564			= "|tip2 Who did not take damage from |sid100214|id (exclude people with/after 7 sec of |sid100215|id) - total"
psfiretxtopt571			= "|tip1 Who triggered |sid98164|id if someone died from it (|cffff0000range check, not 100% accurately|r)"
psfiretxtopt572			= "|tip1 Total damage to Live Meteors if more then 250k (may be excess damage)"
psfiretxtopt573			= "|tip1 After |sid100259|id shows who made damage and stuns to the add"
psfiretxtopt574			= "|tip2 |sid101233|id - who got damage when it spawned, didn`t run away"


psfiretxtoptt533		= "|s4id100359|id got NOT a player! Buff on"
psfiretxtoptt544		= "|s4id99947|id was interrupted by"
psfiretimes			= "times"
psfirebaleroccrystal		= "Crystal"
psfirenotsure			= "not sure"
psfirewith			= "with"
psfireby			= "by" --от
psfirewhodied			= "who died info"
psfireintershanox		= "Interrupted by"
psfirebabah			= "explode"
psfirebabah2			= "Attacks with |s4id98620,100215,100216,100217|id to players"
psfiremajodamag1		= "Everyone got damage!"
psfiremajodamag2		= "|s4id98474,100212,100213,100214|id no damage on"
psfiremajodamag3		= "no damage on"
psfiremaybeexcessd		= "May be excess damage to"
psfireno			= "NO"
psfirefixate1			= "last one finished %s sec ago on"
psfirediddamageto		= "Did damage to"
psfiredamshared			= "explode shared between"
psfireshanaddopt1		= "AoE from the Spear"
psfireshanaddopt2		= "damage from the Spear"
psfireshanaddopt3		= "excess"
psfiretauntseff			= "Taunts used on Cinderweb Spinner (effective)"
psfiretauntseff2		= "Taunts against Cinderweb Spinner"
psfireconsumeadd		= "Cinderweb Drone got |sid100634|id"


end
